
// C++YjYScaleDemoDlg.cpp: 实现文件
//

#include "stdafx.h"
#include "C++YjYScaleDemo.h"
#include "C++YjYScaleDemoDlg.h"
#include "afxdialogex.h"
#include <sstream>
#ifdef _DEBUG
#define new DEBUG_NEW
#endif

// 用于应用程序“关于”菜单项的 CAboutDlg 对话框

class CAboutDlg : public CDialogEx
{
public:
	CAboutDlg();

	// 对话框数据
#ifdef AFX_DESIGN_TIME
	enum { IDD = IDD_ABOUTBOX };
#endif

protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV 支持

// 实现
protected:
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialogEx(IDD_ABOUTBOX)
{
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialogEx::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialogEx)
END_MESSAGE_MAP()


// CCYjYScaleDemoDlg 对话框


CCYjYScaleDemoDlg::CCYjYScaleDemoDlg(CWnd* pParent /*=nullptr*/)
	: CDialogEx(IDD_CYJYSCALEDEMO_DIALOG, pParent)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CCYjYScaleDemoDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialogEx::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CCYjYScaleDemoDlg, CDialogEx)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDOK, &CCYjYScaleDemoDlg::OnBnClickedOk)
	ON_NOTIFY(NM_CUSTOMDRAW, IDC_PROGRESS1, &CCYjYScaleDemoDlg::OnNMCustomdrawProgress1)
	ON_BN_CLICKED(BtPlu, &CCYjYScaleDemoDlg::OnBnClickedBtplu)
	ON_BN_CLICKED(IDC_BtDepartment, &CCYjYScaleDemoDlg::OnBnClickedBtdepartment)
	ON_BN_CLICKED(IDC_BtUnit, &CCYjYScaleDemoDlg::OnBnClickedBtunit)
	ON_BN_CLICKED(IDC_BtHotKey, &CCYjYScaleDemoDlg::OnBnClickedBthotkey)
	ON_BN_CLICKED(IDC_BtHotKey, &CCYjYScaleDemoDlg::OnBnClickedBthotkey)
	ON_BN_CLICKED(BtPlu, &CCYjYScaleDemoDlg::OnBnClickedBtplu)
	ON_BN_CLICKED(IDC_BtDepartment, &CCYjYScaleDemoDlg::OnBnClickedBtdepartment)
	ON_BN_CLICKED(IDC_BtHotKey, &CCYjYScaleDemoDlg::OnBnClickedBthotkey)
	ON_BN_CLICKED(IDC_BtUnit, &CCYjYScaleDemoDlg::OnBnClickedBtunit)
	ON_BN_CLICKED(IDC_BtCustomBarcode, &CCYjYScaleDemoDlg::OnBnClickedBtcustombarcode)
	ON_BN_CLICKED(IDC_BtNote1, &CCYjYScaleDemoDlg::OnBnClickedBtnote1)
	ON_BN_CLICKED(IDC_BtNote2, &CCYjYScaleDemoDlg::OnBnClickedBtnote2)
	ON_BN_CLICKED(IDC_BtNote3, &CCYjYScaleDemoDlg::OnBnClickedBtnote3)
	ON_BN_CLICKED(IDC_BtNote4, &CCYjYScaleDemoDlg::OnBnClickedBtnote4)
	ON_BN_CLICKED(IDC_BtSystemOptions, &CCYjYScaleDemoDlg::OnBnClickedBtsystemoptions)
	ON_BN_CLICKED(IDC_BtTime, &CCYjYScaleDemoDlg::OnBnClickedBttime)
	ON_BN_CLICKED(IDC_BtLable, &CCYjYScaleDemoDlg::OnBnClickedBtlable)
	ON_BN_CLICKED(IDC_BtLableFile, &CCYjYScaleDemoDlg::OnBnClickedBtlablefile)
	ON_BN_CLICKED(IDC_BtLableBackGround, &CCYjYScaleDemoDlg::OnBnClickedBtlablebackground)
	ON_BN_CLICKED(IDC_BtUpPLU, &CCYjYScaleDemoDlg::OnBnClickedBtupplu)
	ON_BN_CLICKED(IDC_BtUpDepartment, &CCYjYScaleDemoDlg::OnBnClickedBtupdepartment)
	ON_BN_CLICKED(IDC_BtUpHotKey, &CCYjYScaleDemoDlg::OnBnClickedBtuphotkey)
	ON_BN_CLICKED(IDC_BtUpCustomBarcode, &CCYjYScaleDemoDlg::OnBnClickedBtupcustombarcode)
	ON_BN_CLICKED(IDC_BtUpNote1, &CCYjYScaleDemoDlg::OnBnClickedBtupnote1)
	ON_BN_CLICKED(IDC_BtUpNote2, &CCYjYScaleDemoDlg::OnBnClickedBtupnote2)
	ON_BN_CLICKED(IDC_BtUpNote3, &CCYjYScaleDemoDlg::OnBnClickedBtupnote3)
	ON_BN_CLICKED(IDC_BtUpNote4, &CCYjYScaleDemoDlg::OnBnClickedBtupnote4)
	ON_BN_CLICKED(IDC_BtUpSystemOptions, &CCYjYScaleDemoDlg::OnBnClickedBtupsystemoptions)
	ON_BN_CLICKED(IDC_BtUpLableFile, &CCYjYScaleDemoDlg::OnBnClickedBtuplablefile)
	ON_BN_CLICKED(IDC_BtDelPlu, &CCYjYScaleDemoDlg::OnBnClickedBtdelplu)
	ON_BN_CLICKED(IDC_BtDelNote1, &CCYjYScaleDemoDlg::OnBnClickedBtdelnote1)
	ON_BN_CLICKED(IDC_BtDelNote2, &CCYjYScaleDemoDlg::OnBnClickedBtdelnote2)
	ON_BN_CLICKED(IDC_BtDelNote3, &CCYjYScaleDemoDlg::OnBnClickedBtdelnote3)
	ON_BN_CLICKED(IDC_BtDelNote4, &CCYjYScaleDemoDlg::OnBnClickedBtdelnote4)
	ON_BN_CLICKED(IDC_BtNote1, &CCYjYScaleDemoDlg::OnBnClickedBtnote1)
	ON_BN_CLICKED(IDC_BtNote2, &CCYjYScaleDemoDlg::OnBnClickedBtnote2)
	ON_BN_CLICKED(IDC_BtNote3, &CCYjYScaleDemoDlg::OnBnClickedBtnote3)
	ON_BN_CLICKED(IDC_BtNote4, &CCYjYScaleDemoDlg::OnBnClickedBtnote4)
	ON_BN_CLICKED(IDC_BtFinalize, &CCYjYScaleDemoDlg::OnBnClickedBtfinalize)
	ON_BN_CLICKED(IDC_BtInit, &CCYjYScaleDemoDlg::OnBnClickedBtinit)
END_MESSAGE_MAP()


// CCYjYScaleDemoDlg 消息处理程序

BOOL CCYjYScaleDemoDlg::OnInitDialog()
{
	CDialogEx::OnInitDialog();

	// 将“关于...”菜单项添加到系统菜单中。

	// IDM_ABOUTBOX 必须在系统命令范围内。
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);
	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != nullptr)
	{
		BOOL bNameValid;
		CString strAboutMenu;
		bNameValid = strAboutMenu.LoadString(IDS_ABOUTBOX);
		ASSERT(bNameValid);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}
	// 设置此对话框的图标。  当应用程序主窗口不是对话框时，框架将自动
	//  执行此操作
	SetIcon(m_hIcon, TRUE);			// 设置大图标
	SetIcon(m_hIcon, FALSE);		// 设置小图标
	// TODO: 在此添加额外的初始化代码
	init();
	return TRUE;  // 除非将焦点设置到控件，否则返回 TRUE
}

void CCYjYScaleDemoDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		CDialogEx::OnSysCommand(nID, lParam);
	}
}

// 如果向对话框添加最小化按钮，则需要下面的代码
//  来绘制该图标。  对于使用文档/视图模型的 MFC 应用程序，
//  这将由框架自动完成。

void CCYjYScaleDemoDlg::OnPaint()
{
	if (IsIconic())
	{
		CPaintDC dc(this); // 用于绘制的设备上下文
		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);
		// 使图标在工作区矩形中居中
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;
		// 绘制图标
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialogEx::OnPaint();
	}
}

//当用户拖动最小化窗口时系统调用此函数取得光标
//显示。
HCURSOR CCYjYScaleDemoDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}

void CCYjYScaleDemoDlg::OnBnClickedOk()
{
	//cstring addr1;
	//((cedit*)getdlgitem(idc_edit3))->getwindowtext(addr1);
	//std::wstring ws1(addr1);
	//std::string addr;
	//addr.assign(ws1.begin(), ws1.end());
	//cstring filename, filename1;
	//tchar _szpath[max_path + 1] = { 0 };
	//getmodulefilename(null, _szpath, max_path);
	//(_tcsrchr(_szpath, _t('\\')))[1] = 0;//删除文件名，只获得路径 字串
	//cstring strpath;
	//for (int n = 0; _szpath[n]; n++)
	//{
	//	if (_szpath[n] != _t('\\'))
	//	{
	//		strpath += _szpath[n];
	//	}
	//	else
	//	{
	//		strpath += _t('\\');
	//	}
	//}
	//filename1 = "plu.txt";
	//filename = strpath + filename1;
	//std::wstring ws(filename);
	//std::string s;
	//s.assign(ws.begin(), ws.end());
	//hwnd hwnd = afxgetmainwnd()->m_hwnd;
	//transferitem(addr, s, hwnd);

	// TODO: 在此添加控件通知处理程序代码
//	CDialogEx::OnOK();

//	CString  filename1;
	//filename1 = returnFileName(Sync_DataType_PLU);

	//setnew(Sync_DataType_PLU);


//	transferItem(Sync_DataType_PLU, GetIP(), s, hWnd);
	DownFileAdrr(Sync_DataType_PLU, GetIP(), AfxGetMainWnd()->m_hWnd);
}


void CCYjYScaleDemoDlg::OnNMCustomdrawProgress1(NMHDR *pNMHDR, LRESULT *pResult)
{
	//////LPNMCUSTOMDRAW pNMCD = reinterpret_cast<LPNMCUSTOMDRAW>(pNMHDR);
	// TODO: 在此添加控件通知处理程序代码
	*pResult = 0;

	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetRange(0, 100);
	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetPos(60);
}

void CCYjYScaleDemoDlg::setnew(int ADataType)
{
	/*CString addr1;
	((CEdit*)GetDlgItem(IDC_EDIT3))->GetWindowText(addr1);
	std::wstring ws1(addr1);
	std::string addr;
	addr.assign(ws1.begin(), ws1.end());*/
	//CString fileName, fileName1;
	//TCHAR _szPath[MAX_PATH + 1] = { 0 };
	//GetModuleFileName(NULL, _szPath, MAX_PATH);
	//(_tcsrchr(_szPath, _T('\\')))[1] = 0;//删除文件名，只获得路径 字串
	//CString strPath;
	//for (int n = 0; _szPath[n]; n++)
	//{
	//	if (_szPath[n] != _T('\\'))
	//	{
	//		strPath += _szPath[n];
	//	}
	//	else
	//	{
	//		strPath += _T('\\');
	//	}
	//}
	////fileName1 = "PLU.txt";
	//fileName1 = returnFileName(ADataType);
	//fileName = strPath + fileName1;
	//std::wstring ws(fileName);
	//std::string s;
	//s.assign(ws.begin(), ws.end());
	//string addr;
	//addr = GetIP();
	//HWND hWnd = AfxGetMainWnd()->m_hWnd;
	//transferItem(ADataType,addr, s, hWnd);
	DownFileAdrr(ADataType, GetIP(), AfxGetMainWnd()->m_hWnd);
}


void CCYjYScaleDemoDlg::showProgress(int index, int total)
{
	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetPos(index);

}


void CCYjYScaleDemoDlg::setProgress(int total)
{
	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetRange(0, total);


}

string CCYjYScaleDemoDlg::GetIP()
{
	CString addr1;
	((CEdit*)GetDlgItem(IDC_EDIT3))->GetWindowText(addr1);
	std::wstring ws1(addr1);
	std::string addr;
	addr.assign(ws1.begin(), ws1.end());
	return addr;
}


void  CCYjYScaleDemoDlg::setProgressRange(int total, int index)
{
	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetRange(0, total);
	((CProgressCtrl*)GetDlgItem(IDC_PROGRESS1))->SetPos(index);
}



void CCYjYScaleDemoDlg::OnBnClickedBtHotkey()
{
	DownFileAdrr(Sync_DataType_Hotkey, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtplu()
{
	DownFileAdrr(Sync_DataType_PLU, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdepartment()
{
	DownFileAdrr(Sync_DataType_Department, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBthotkey()
{
	// TODO: 在此添加控件通知处理程序代码
	DownFileAdrr(Sync_DataType_Hotkey, GetIP(), AfxGetMainWnd()->m_hWnd);
}


void CCYjYScaleDemoDlg::OnBnClickedBtunit()
{
	DownFileAdrr(Sync_DataType_Unit, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtcustombarcode()
{
	DownFileAdrr(Sync_DataType_CustomBarcode, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtsystemoptions()
{
	DownFileAdrr(Sync_DataType_SystemOptions, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBttime()
{
	DownFileAdrr(Sync_DataType_Time, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtlable()
{

	DownFileAdrr(Sync_DataType_Label, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtlablefile()
{
	DownFileAdrr(Sync_DataType_LabelFile, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtlablebackground()
{
	DownFileAdrr(Sync_DataType_LabelBackGround, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupplu()
{
	UpFileAdrr(Sync_DataType_PLU, GetIP(), AfxGetMainWnd()->m_hWnd);

	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupdepartment()
{
	UpFileAdrr(Sync_DataType_Department, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtuphotkey()
{
	UpFileAdrr(Sync_DataType_Hotkey, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupcustombarcode()
{
	UpFileAdrr(Sync_DataType_CustomBarcode, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupnote1()
{
	UpFileAdrr(Sync_DataType_Note1, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupnote2()
{
	UpFileAdrr(Sync_DataType_Note2, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupnote3()
{
	UpFileAdrr(Sync_DataType_Note3, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupnote4()
{
	UpFileAdrr(Sync_DataType_Note4, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtupsystemoptions()
{
	UpFileAdrr(Sync_DataType_SystemOptions, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtuplablefile()
{
	UpFileAdrr(Sync_DataType_LabelFile, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdelplu()
{
	DelFileAdrr(Sync_DataType_PLU, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdelnote1()
{
	DelFileAdrr(Sync_DataType_Note1, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdelnote2()
{
	DelFileAdrr(Sync_DataType_Note2, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdelnote3()
{
	DelFileAdrr(Sync_DataType_Note3, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtdelnote4()
{
	DelFileAdrr(Sync_DataType_Note4, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtnote1()
{
	DownFileAdrr(Sync_DataType_Note1, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtnote2()
{
	DownFileAdrr(Sync_DataType_Note2, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtnote3()
{
	DownFileAdrr(Sync_DataType_Note3, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtnote4()
{
	DownFileAdrr(Sync_DataType_Note4, GetIP(), AfxGetMainWnd()->m_hWnd);
	// TODO: 在此添加控件通知处理程序代码
}

void CCYjYScaleDemoDlg::OnBnClickedBtfinalize()
{
	FinalizeFree();
	// TODO: 在此添加控件通知处理程序代码
}


void CCYjYScaleDemoDlg::OnBnClickedBtinit()
{
	init();
	// TODO: 在此添加控件通知处理程序代码
}
